@@ -46,7 +46,7 @@ from neutron.common import utils
 from neutron import manager
 
 LOG = logging.getLogger(__name__)
-_SYNC_STATE_LOCK = lockutils.ReaderWriterLock()
+_SYNC_STATE_LOCK = threading.RLock()
 
 DEFAULT_PRIORITY = 255
 
@@ -61,7 +61,7 @@ def _sync_lock(f):
     """Decorator to block all operations for a global sync call."""
     @functools.wraps(f)
     def wrapped(*args, **kwargs):
-        with _SYNC_STATE_LOCK.write_lock():
+        with _SYNC_STATE_LOCK:
             return f(*args, **kwargs)
     return wrapped
 
@@ -70,7 +70,7 @@ def _wait_if_syncing(f):
     """Decorator to wait if any sync operations are in progress."""
     @functools.wraps(f)
     def wrapped(*args, **kwargs):
-        with _SYNC_STATE_LOCK.read_lock():
+        with _SYNC_STATE_LOCK:
             return f(*args, **kwargs)
     return wrapped
 
@@ -85,10 +85,10 @@ class DHCPResourceUpdate(queue.ResourceUpdate):
 
     def __lt__(self, other):
         if other.obj_type == self.obj_type == 'port':
-            self_ips = set(str(fixed_ip['ip_address']) for
-                           fixed_ip in self.resource['fixed_ips'])
-            other_ips = set(str(fixed_ip['ip_address']) for
-                            fixed_ip in other.resource['fixed_ips'])
+            self_ips = {str(fixed_ip['ip_address']) for
+                        fixed_ip in self.resource['fixed_ips']}
+            other_ips = {str(fixed_ip['ip_address']) for
+                         fixed_ip in other.resource['fixed_ips']}
             if self_ips & other_ips:
                 return self.timestamp < other.timestamp
 
@@ -107,7 +107,7 @@ class DhcpAgent(manager.Manager):
     target = oslo_messaging.Target(version='1.0')
 
     def __init__(self, host=None, conf=None):
-        super(DhcpAgent, self).__init__(host=host)
+        super().__init__(host=host)
         self.needs_resync_reasons = collections.defaultdict(list)
         self.dhcp_ready_ports = set()
         self.dhcp_prio_ready_ports = set()
@@ -226,10 +226,8 @@ class DhcpAgent(manager.Manager):
                     action, network, segment=sid_segment.get(seg_id),
                     **action_kwargs))
             return all(ret)
-        else:
-            # In case subnets are not attached to segments. default behavior.
-            return self._call_driver(
-                action, network, **action_kwargs)
+        # In case subnets are not attached to segments. default behavior.
+        return self._call_driver(action, network, **action_kwargs)
 
     def _call_driver(self, action, network, segment=None, **action_kwargs):
         """Invoke an action on a DHCP driver instance."""
@@ -251,11 +249,12 @@ class DhcpAgent(manager.Manager):
                                           self.dhcp_version,
                                           self.plugin_rpc,
                                           segment)
+            # NOTE(ihrachys) It's important that we always call the action
+            # before deciding what to return!
             rv = getattr(driver, action)(**action_kwargs)
             if action == 'get_metadata_bind_interface':
                 return rv
-            else:
-                return True
+            return True
         except exceptions.Conflict:
             # No need to resync here, the agent will receive the event related
             # to a status update for the network
@@ -309,7 +308,7 @@ class DhcpAgent(manager.Manager):
             active_networks = self.plugin_rpc.get_active_networks_info(
                 enable_dhcp_filter=False)
             LOG.info('All active networks have been fetched through RPC.')
-            active_network_ids = set(network.id for network in active_networks)
+            active_network_ids = {network.id for network in active_networks}
             for deleted_id in known_network_ids - active_network_ids:
                 try:
                     self.disable_dhcp_helper(deleted_id)
@@ -654,7 +653,7 @@ class DhcpAgent(manager.Manager):
                 self.schedule_resync("Agent port was modified",
                                      port.network_id)
                 return
-            elif old_ips != new_ips:
+            if old_ips != new_ips:
                 LOG.debug("Agent IPs on network %s changed from %s to %s",
                           network.id, old_ips, new_ips)
                 driver_action = 'restart'
@@ -940,7 +939,7 @@ class DhcpPluginApi(base_agent_rpc.BasePluginApi):
         return [dhcp.NetModel(net) for net in nets]
 
 
-class NetworkCache(object):
+class NetworkCache:
     """Agent cache of the current network state."""
     def __init__(self):
         self.cache = {}
@@ -1071,7 +1070,7 @@ class NetworkCache(object):
 
 class DhcpAgentWithStateReport(DhcpAgent):
     def __init__(self, host=None, conf=None):
-        super(DhcpAgentWithStateReport, self).__init__(host=host, conf=conf)
+        super().__init__(host=host, conf=conf)
         self.state_rpc = agent_rpc.PluginReportStateAPI(topics.REPORTS)
         self.failed_report_state = False
         self.agent_state = {
