@@ -32,6 +32,7 @@ from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import timeutils
 from ovsdbapp.backend.ovs_idl import event as row_event
+from ovsdbapp.backend.ovs_idl import rowview
 
 from neutron.common.ovn import constants as ovn_const
 from neutron.common.ovn import utils
@@ -42,6 +43,8 @@ from neutron.db import ovn_revision_numbers_db as revision_numbers_db
 from neutron.objects import network as network_obj
 from neutron.objects import ports as ports_obj
 from neutron.objects import router as router_obj
+from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb.extensions import qos \
+    as qos_extension
 from neutron import service
 from neutron.services.logapi.drivers.ovn import driver as log_driver
 
@@ -1134,6 +1137,29 @@ class DBInconsistenciesPeriodics(SchemaAwarePeriodicsBase):
 
         raise periodics.NeverAgain()
 
+    # TODO(ralonsoh): to remove in E+4 cycle (2nd next SLURP release)
+    @has_lock_periodic(
+        periodic_run_limit=ovn_const.MAINTENANCE_TASK_RETRY_LIMIT,
+        spacing=ovn_const.MAINTENANCE_ONE_RUN_TASK_SPACING,
+        run_immediately=True)
+    def update_qos_fip_rule_priority(self):
+        """The new QoS FIP rule priority is OVN_QOS_FIP_RULE_PRIORITY"""
+        cmds = []
+        table = self._nb_idl.tables['QoS']
+        for qos_rule in table.rows.values():
+            qos_rule = rowview.RowView(qos_rule)
+            if qos_rule.external_ids.get(ovn_const.OVN_FIP_EXT_ID_KEY):
+                cmds.append(self._nb_idl.db_set(
+                    'QoS', qos_rule.uuid,
+                    ('priority', qos_extension.OVN_QOS_FIP_RULE_PRIORITY)))
+
+        if cmds:
+            with self._nb_idl.transaction(check_error=True) as txn:
+                for cmd in cmds:
+                    txn.add(cmd)
+
+        raise periodics.NeverAgain()
+
 
 class HashRingHealthCheckPeriodics:
 
