@@ -421,3 +421,43 @@ class DHCPAgentOVSTestCase(DHCPAgentOVSTestFramework):
             exception=RuntimeError("'dhcp_ready_on_ports' not be called"))
         self.mock_plugin_api.dhcp_ready_on_ports.assert_called_with(
             ports_to_send)
+
+    def test_dhcp_processing_pool_size(self):
+        mock.patch.object(self.agent, 'call_driver').start().return_value = (
+            True)
+        self.agent.update_isolated_metadata_proxy = mock.Mock()
+        self.agent.disable_isolated_metadata_proxy = mock.Mock()
+
+        network_info_1 = self.network_dict_for_dhcp()
+        self.configure_dhcp_for_network(network=network_info_1)
+        self.assertEqual(agent.DHCP_PROCESS_GREENLET_MIN,
+                         self.agent._pool.size)
+
+        network_info_2 = self.network_dict_for_dhcp()
+        self.configure_dhcp_for_network(network=network_info_2)
+        self.assertEqual(agent.DHCP_PROCESS_GREENLET_MIN,
+                         self.agent._pool.size)
+
+        network_info_list = [network_info_1, network_info_2]
+        for _i in range(agent.DHCP_PROCESS_GREENLET_MAX + 1):
+            ni = self.network_dict_for_dhcp()
+            self.configure_dhcp_for_network(network=ni)
+            network_info_list.append(ni)
+
+        self.assertEqual(agent.DHCP_PROCESS_GREENLET_MAX,
+                         self.agent._pool.size)
+
+        for network in network_info_list:
+            self.agent.disable_dhcp_helper(network.id)
+
+        agent_network_info_len = len(self.agent.cache.get_network_ids())
+        if agent_network_info_len < agent.DHCP_PROCESS_GREENLET_MIN:
+            self.assertEqual(agent.DHCP_PROCESS_GREENLET_MIN,
+                             self.agent._pool.size)
+        elif (agent.DHCP_PROCESS_GREENLET_MIN <= agent_network_info_len <=
+              agent.DHCP_PROCESS_GREENLET_MAX):
+            self.assertEqual(agent_network_info_len,
+                             self.agent._pool.size)
+        else:
+            self.assertEqual(agent.DHCP_PROCESS_GREENLET_MAX,
+                             self.agent._pool.size)
