@@ -34,6 +34,7 @@ from ovsdbapp.backend.ovs_idl import idlutils
 from neutron.agent.linux import utils
 from neutron.api import extensions as exts
 from neutron.api import wsgi
+from neutron.common.ovn import constants as ovn_const
 from neutron.common import utils as n_utils
 from neutron.conf.agent import common as config
 from neutron.conf.agent import ovs_conf
@@ -105,7 +106,7 @@ class BaseSudoTestCase(BaseLoggingTestCase):
     """
 
     def setUp(self):
-        super(BaseSudoTestCase, self).setUp()
+        super().setUp()
         if not base.bool_from_env('OS_SUDO_TESTING'):
             self.skipTest('Testing with sudo is not enabled')
         self.setup_rootwrap()
@@ -141,7 +142,10 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
     OVN_DISTRIBUTION = 'ovn'
     OVN_SCHEMA_FILES = ['ovn-nb.ovsschema', 'ovn-sb.ovsschema']
 
-    _mechanism_drivers = ['logger', 'ovn']
+    # NOTE(ralonsoh): during the eventlet removal, the "logger" mech
+    # driver has been removed from this list. Re-add it once the removal
+    # is finished or the mech driver does not call monkey_patch().
+    _mechanism_drivers = ['ovn']
     _extension_drivers = ['port_security', 'external-gateway-multihoming']
     _counter = 0
     l3_plugin = 'neutron.services.ovn_l3.plugin.OVNL3RouterPlugin'
@@ -152,14 +156,14 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
 
     def setUp(self, maintenance_worker=False, service_plugins=None):
         ml2_config.cfg.CONF.set_override('extension_drivers',
-                                     self._extension_drivers,
-                                     group='ml2')
+                                         self._extension_drivers,
+                                         group='ml2')
         ml2_config.cfg.CONF.set_override('tenant_network_types',
-                                     ['geneve'],
-                                     group='ml2')
+                                         ['geneve'],
+                                         group='ml2')
         ml2_config.cfg.CONF.set_override('vni_ranges',
-                                     ['1:65536'],
-                                     group='ml2_type_geneve')
+                                         ['1:500'],
+                                         group='ml2_type_geneve')
         # ensure viable minimum is set for OVN's Geneve
         ml2_config.cfg.CONF.set_override('max_header_size', 38,
                                          group='ml2_type_geneve')
@@ -173,7 +177,7 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         self.ovsdb_server_mgr = None
         self._service_plugins = service_plugins
         log_driver.DRIVER = None
-        super(TestOVNFunctionalBase, self).setUp()
+        super().setUp()
         self.test_log_dir = os.path.join(DEFAULT_LOG_DIR, self.id())
         base.setup_test_logging(
             cfg.CONF, self.test_log_dir, "testrun.txt")
@@ -243,7 +247,7 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
                     errno.ENOENT, os.strerror(errno.ENOENT), msg)
 
     def get_additional_service_plugins(self):
-        p = super(TestOVNFunctionalBase, self).get_additional_service_plugins()
+        p = super().get_additional_service_plugins()
         p.update({'revision_plugin_name': 'revisions',
                   'segments': 'neutron.services.segments.plugin.Plugin'})
         if self._service_plugins:
@@ -308,11 +312,10 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         LOG.debug("OVSDB server manager instantiated: %r",
                   self.ovsdb_server_mgr)
         set_cfg = cfg.CONF.set_override
-        set_cfg('ovn_nb_connection',
-                self.ovsdb_server_mgr.get_ovsdb_connection_path(), 'ovn')
-        set_cfg('ovn_sb_connection',
-                self.ovsdb_server_mgr.get_ovsdb_connection_path(
-                    db_type='sb'), 'ovn')
+        ovn_nb_db = self.ovsdb_server_mgr.get_ovsdb_connection_path('nb')
+        set_cfg('ovn_nb_connection', [ovn_nb_db], 'ovn')
+        ovn_sb_db = self.ovsdb_server_mgr.get_ovsdb_connection_path('sb')
+        set_cfg('ovn_sb_connection', [ovn_sb_db], 'ovn')
         set_cfg('ovn_nb_private_key', self.ovsdb_server_mgr.private_key, 'ovn')
         set_cfg('ovn_nb_certificate', self.ovsdb_server_mgr.certificate, 'ovn')
         set_cfg('ovn_nb_ca_cert', self.ovsdb_server_mgr.ca_cert, 'ovn')
@@ -336,7 +339,8 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         trigger_cls = TriggerCls()
         if self.maintenance_worker:
             trigger_cls.trigger.__self__.__class__ = worker.MaintenanceWorker
-            cfg.CONF.set_override('neutron_sync_mode', 'off', 'ovn')
+            cfg.CONF.set_override(
+                'neutron_sync_mode', ovn_const.OVN_DB_SYNC_MODE_OFF, 'ovn')
         else:
             trigger_cls.trigger.__self__.__class__ = wsgi.WorkerService
 
@@ -359,15 +363,15 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         timestamp = datetime.now().strftime('%y-%m-%d_%H-%M-%S')
         for database in ("nb", "sb"):
             for file_suffix in ("log", "db"):
-                src_filename = "ovn_%(db)s.%(suffix)s" % {
-                    'db': database,
-                    'suffix': file_suffix
-                }
-                dst_filename = "ovn_%(db)s-%(timestamp)s.%(suffix)s" % {
-                    'db': database,
-                    'suffix': file_suffix,
-                    'timestamp': timestamp,
-                }
+                src_filename = "ovn_{db}.{suffix}".format(
+                    db=database,
+                    suffix=file_suffix
+                )
+                dst_filename = "ovn_{db}-{timestamp}.{suffix}".format(
+                    db=database,
+                    suffix=file_suffix,
+                    timestamp=timestamp,
+                )
                 try:
                     self._copy_log_file(src_filename, dst_filename)
                 except FileNotFoundError:
@@ -378,10 +382,10 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
 
         # Copy northd logs
         northd_log = "ovn_northd"
-        dst_northd = "%(northd)s-%(timestamp)s.log" % {
-            "northd": northd_log,
-            "timestamp": timestamp,
-        }
+        dst_northd = "{northd}-{timestamp}.log".format(
+            northd=northd_log,
+            timestamp=timestamp,
+        )
         self._copy_log_file("%s.log" % northd_log, dst_northd)
 
     def _copy_log_file(self, src_filename, dst_filename):
@@ -401,7 +405,7 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
             except Exception:  # pylint:disable=bare-except
                 pass
 
-    def restart(self):
+    def restart(self, delete_dbs=True):
         self.stop()
 
         if self.ovsdb_server_mgr:
@@ -409,7 +413,8 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         if self.ovn_northd_mgr:
             self.ovn_northd_mgr.stop()
 
-        self.ovsdb_server_mgr.delete_dbs()
+        if delete_dbs:
+            self.ovsdb_server_mgr.delete_dbs()
         self._start_ovsdb_server()
         self._start_idls()
         self._start_ovn_northd()
@@ -436,7 +441,7 @@ class TestOVNFunctionalBase(test_plugin.Ml2PluginV2TestCase,
         if enable_chassis_as_extport:
             append_cms_options(other_config, 'enable-chassis-as-extport-host')
 
-        bridge_mapping = ",".join(["%s:br-provider%s" % (phys_net, i)
+        bridge_mapping = ",".join(["{}:br-provider{}".format(phys_net, i)
                                   for i, phys_net in enumerate(physical_nets)])
         if name is None:
             name = uuidutils.generate_uuid()
