@@ -56,7 +56,7 @@ class WaitForDataPathBindingCreateEvent(event.WaitEvent):
         table = 'Datapath_Binding'
         events = (self.ROW_CREATE,)
         conditions = (('external_ids', '=', {'name2': net_name}),)
-        super(WaitForDataPathBindingCreateEvent, self).__init__(
+        super().__init__(
             events, table, conditions, timeout=15)
 
 
@@ -69,6 +69,22 @@ class WaitForChassisPrivateCreateEvent(event.WaitEvent):
         super().__init__(events, 'Chassis_Private', conditions, timeout=15)
 
 
+class WaitForPortBindingFIPEvent(event.WaitEvent):
+    event_name = 'WaitForPortBindingFIPEvent'
+
+    def __init__(self, fip):
+        events = (self.ROW_UPDATE, )
+        self._fip = fip
+        super().__init__(events, 'Port_Binding', {}, timeout=15)
+
+    def match_fn(self, event, row, old=None):
+        try:
+            return (row.external_ids[ovn_const.OVN_PORT_FIP_EXT_ID_KEY] ==
+                    self._fip)
+        except (AttributeError, KeyError):
+            return False
+
+
 class DistributedLockTestEvent(event.WaitEvent):
     ONETIME = False
     COUNTER = 0
@@ -76,7 +92,7 @@ class DistributedLockTestEvent(event.WaitEvent):
     def __init__(self):
         table = 'Logical_Switch_Port'
         events = (self.ROW_CREATE,)
-        super(DistributedLockTestEvent, self).__init__(
+        super().__init__(
             events, table, (), timeout=15)
         self.event_name = 'DistributedLockTestEvent'
 
@@ -111,7 +127,7 @@ class TestNBDbMonitor(testlib_api.MySQLTestCaseMixin,
                       base.TestOVNFunctionalBase):
 
     def setUp(self):
-        super(TestNBDbMonitor, self).setUp()
+        super().setUp()
         self.assertEqual(mysql_dialect.name, self.db.engine.dialect.name)
         self.chassis = self.add_fake_chassis('ovs-host1')
         self.l3_plugin = directory.get_plugin(plugin_constants.L3)
@@ -219,10 +235,15 @@ class TestNBDbMonitor(testlib_api.MySQLTestCaseMixin,
         port = self.create_port()
 
         # Ensure that the MAC_Binding entry gets deleted after creating a FIP
+        fip_event = WaitForPortBindingFIPEvent('100.0.0.21')
+        self.mech_driver.sb_ovn.idl.notify_handler.watch_event(fip_event)
         fip = self._create_fip(port, '100.0.0.21')
+        self.assertTrue(fip_event.wait())
+        # TODO(ralonsoh): restore the timeout=15 value (or even lower) once
+        # the eventlet removal finishes.
         n_utils.wait_until_true(
             lambda: not self._check_mac_binding_exists(macb_id),
-            timeout=15, sleep=1)
+            timeout=30, sleep=1)
 
         # Now that the FIP is created, add a new MAC_Binding entry with the
         # same IP address
@@ -231,9 +252,11 @@ class TestNBDbMonitor(testlib_api.MySQLTestCaseMixin,
 
         # Ensure that the MAC_Binding entry gets deleted after deleting the FIP
         self.l3_plugin.delete_floatingip(self.context, fip['id'])
+        # TODO(ralonsoh): restore the timeout=15 value (or even lower) once
+        # the eventlet removal finishes.
         n_utils.wait_until_true(
             lambda: not self._check_mac_binding_exists(macb_id),
-            timeout=15, sleep=1)
+            timeout=30, sleep=1)
 
     def _test_port_binding_and_status(self, port_id, action, status):
         # This function binds or unbinds port to chassis and
@@ -682,7 +705,7 @@ class TestAgentMonitor(base.TestOVNFunctionalBase):
     FAKE_CHASSIS_HOST = 'fake-chassis-host'
 
     def setUp(self):
-        super(TestAgentMonitor, self).setUp()
+        super().setUp()
         self.l3_plugin = directory.get_plugin(plugin_constants.L3)
         self.mock_ovsdb_idl = mock.Mock()
         self.handler = self.sb_api.idl.notify_handler
@@ -701,19 +724,25 @@ class TestAgentMonitor(base.TestOVNFunctionalBase):
         self.assertIsInstance(
             neutron_agent.AgentCache().get(self.chassis_name),
             neutron_agent.ControllerGatewayAgent)
-        self.sb_api.db_set('Chassis', self.chassis_name, ('other_config',
-            {'ovn-cms-options': ''})).execute(check_error=True)
-        n_utils.wait_until_true(lambda:
+        self.sb_api.db_set(
+            'Chassis', self.chassis_name,
+            ('other_config',
+             {'ovn-cms-options': ''})).execute(check_error=True)
+        n_utils.wait_until_true(
+            lambda:
             isinstance(neutron_agent.AgentCache().get(self.chassis_name),
-                       neutron_agent.ControllerAgent))
+            neutron_agent.ControllerAgent))
 
         # Change back to gw chassis
-        self.sb_api.db_set('Chassis', self.chassis_name, ('other_config',
-            {'ovn-cms-options': 'enable-chassis-as-gw'})).execute(
-                check_error=True)
-        n_utils.wait_until_true(lambda:
+        self.sb_api.db_set(
+            'Chassis', self.chassis_name,
+            ('other_config',
+             {'ovn-cms-options': 'enable-chassis-as-gw'})).execute(
+                 check_error=True)
+        n_utils.wait_until_true(
+            lambda:
             isinstance(neutron_agent.AgentCache().get(self.chassis_name),
-                       neutron_agent.ControllerGatewayAgent))
+            neutron_agent.ControllerGatewayAgent))
 
     def test_agent_updated_at_use_nb_cfg_timestamp(self):
         def check_agent_ts():
@@ -732,7 +761,7 @@ class TestAgentMonitor(base.TestOVNFunctionalBase):
         # Also increment nb_cfg by 1 to trigger ChassisAgentWriteEvent which
         # is responsible to update AgentCache
         old_nb_cfg = self.sb_api.db_get('Chassis_Private', self.chassis_name,
-            'nb_cfg').execute(check_error=True)
+                                        'nb_cfg').execute(check_error=True)
         self.sb_api.db_set('Chassis_Private', self.chassis_name, (
             'nb_cfg', old_nb_cfg + 1)).execute(check_error=True)
         try:
