@@ -30,7 +30,6 @@ from neutron.tests.unit.plugins.ml2.drivers.ovn.mech_driver import \
     test_mech_driver
 from neutron.tests.unit.services.logapi.drivers.ovn import test_driver
 
-
 OvnPortInfo = collections.namedtuple('OvnPortInfo', ['name'])
 
 
@@ -40,7 +39,8 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
     l3_plugin = 'ovn-router'
 
     def setUp(self):
-        super(TestOvnNbSyncML2, self).setUp()
+        # We want metadata enabled to increase coverage
+        super().setUp(enable_metadata=True)
 
         self.test_log_driver = test_driver.TestOVNDriver()
         self.subnet = {'cidr': '10.0.0.0/24',
@@ -125,7 +125,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
             {'id': 'sg1', 'tenant_id': 'tenant1',
              'security_group_rules': [{'remote_group_id': None,
                                        'direction': 'ingress',
-                                       'remote_ip_prefix': '0.0.0.0/0',
+                                       'remote_ip_prefix': const.IPv4_ANY,
                                        'protocol': 'tcp',
                                        'ethertype': 'IPv4',
                                        'tenant_id': 'tenant1',
@@ -137,7 +137,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
             {'id': 'sg2', 'tenant_id': 'tenant1',
              'security_group_rules': [{'remote_group_id': 'sg2',
                                        'direction': 'egress',
-                                       'remote_ip_prefix': '0.0.0.0/0',
+                                       'remote_ip_prefix': const.IPv4_ANY,
                                        'protocol': 'tcp',
                                        'ethertype': 'IPv4',
                                        'tenant_id': 'tenant1',
@@ -263,7 +263,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                   'ip_address': '90.0.0.2'}]}},
                         {'id': 'r2', 'routes': [{'nexthop': '40.0.0.100',
                          'destination': '30.0.0.0/24',
-                         'external_ids': {}}],
+                                                 'external_ids': {}}],
                          'gw_port_id': 'gpr2',
                          'external_gateway_info': {
                              'network_id': "ext-net", 'enable_snat': True,
@@ -358,7 +358,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         self.lrport_networks = ['fdad:123:456::1/64', 'fdad:cafe:a1b2::1/64']
 
     def get_additional_service_plugins(self):
-        p = super(TestOvnNbSyncML2, self).get_additional_service_plugins()
+        p = super().get_additional_service_plugins()
         p.update({'segments': 'neutron.services.segments.plugin.Plugin'})
         return p
 
@@ -411,6 +411,20 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                     segs.append(segment)
             return segs
 
+        def get_ports():
+            def wrapper(*args, **kwargs):
+                # We need to do this since blindly returning self.ports
+                # if caller specified a filter could lead to failed tests,
+                # for example, it will not filter out non-metadata ports.
+                filters = kwargs.get('filters')
+                if not filters:
+                    return self.ports
+                ports = [port for port in self.ports if
+                         all(port[k] in v for k, v in filters.items())]
+                return ports
+
+            return wrapper
+
         segments_plugin.get_segments = mock.Mock()
         segments_plugin.get_segments.side_effect = (
             lambda x, filters: get_segments(self, filters))
@@ -424,7 +438,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         # So, in this example 17 will be added, 2 removed
 
         core_plugin.get_ports = mock.Mock()
-        core_plugin.get_ports.return_value = self.ports
+        core_plugin.get_ports.side_effect = get_ports()
         mock.patch.object(acl, '_get_subnet_from_cache',
                           return_value=self.subnet).start()
         mock.patch.object(acl, 'acl_remote_group_id',
@@ -493,10 +507,10 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         ovn_api.transaction = mock.MagicMock()
 
         ovn_nb_synchronizer._ovn_client.create_network = mock.Mock()
-        ovn_nb_synchronizer._ovn_client.create_port = mock.Mock()
         ovn_driver.validate_and_get_data_from_binding_profile = mock.Mock()
         ovn_nb_synchronizer._ovn_client.create_port = mock.Mock()
         ovn_nb_synchronizer._ovn_client.create_port.return_value = mock.ANY
+        ovn_nb_synchronizer._ovn_client.create_metadata_port = mock.Mock()
         ovn_nb_synchronizer._ovn_client.create_provnet_port = mock.Mock()
         ovn_api.ls_del = mock.Mock()
         ovn_api.delete_lswitch_port = mock.Mock()
@@ -586,6 +600,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                  delete_dhcp_options_list,
                                  add_port_groups_list,
                                  del_port_groups_list,
+                                 create_metadata_list,
                                  test_logging=False):
         self._test_mocks_helper(ovn_nb_synchronizer, test_logging)
 
@@ -618,6 +633,14 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         ovn_nb_synchronizer._ovn_client.create_network.assert_has_calls(
             create_network_calls, any_order=True)
 
+        create_metadata_calls = [mock.call(mock.ANY, net)
+                                 for net in create_metadata_list]
+        self.assertEqual(
+            len(create_metadata_list),
+            ovn_nb_synchronizer._ovn_client.create_metadata_port.call_count)
+        ovn_nb_synchronizer._ovn_client.create_metadata_port.assert_has_calls(
+            create_metadata_calls, any_order=True)
+
         self.assertEqual(
             len(create_port_list),
             ovn_nb_synchronizer._ovn_client.create_port.call_count)
@@ -630,7 +653,8 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
             mock.call(
                 network['id'],
                 self.segments_map[network['id']],
-                txn=mock.ANY)
+                txn=mock.ANY,
+                network=network)
             for network in create_provnet_port_list
             if network.get('provider:physical_network')]
         self.assertEqual(
@@ -664,7 +688,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         self.assertEqual(len(add_static_route_list),
                          ovn_api.add_static_route.call_count)
         routes_to_delete = [(route['destination'], route['nexthop'])
-                           for route in del_static_route_list]
+                            for route in del_static_route_list]
         del_route_call = [mock.call(mock.ANY, routes_to_delete)] \
             if routes_to_delete else []
 
@@ -806,7 +830,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                   'destination': '12.0.0.0/24',
                                   'external_ids': {}},
                                  {'nexthop': '90.0.0.1',
-                                  'destination': '0.0.0.0/0',
+                                  'destination': const.IPv4_ANY,
                                   'external_ids': {
                                       ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
                                       ovn_const.OVN_SUBNET_EXT_ID_KEY:
@@ -815,7 +839,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                   'destination': '30.0.0.0/24',
                                   'external_ids': {}},
                                  {'nexthop': '100.0.0.1',
-                                  'destination': '0.0.0.0/0',
+                                  'destination': const.IPv4_ANY,
                                   'external_ids': {
                                       ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
                                       ovn_const.OVN_SUBNET_EXT_ID_KEY:
@@ -869,10 +893,11 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         add_subnet_dhcp_options_list = [(self.subnets[2], self.networks[1]),
                                         (self.subnets[1], self.networks[0])]
         delete_dhcp_options_list = ['UUID2', 'UUID4', 'UUID5']
+        create_metadata_list = self.networks
 
         ovn_nb_synchronizer = ovn_db_sync.OvnNbSynchronizer(
             self.plugin, self.mech_driver.nb_ovn, self.mech_driver.sb_ovn,
-            'repair', self.mech_driver)
+            ovn_const.OVN_DB_SYNC_MODE_REPAIR, self.mech_driver)
         self._test_ovn_nb_sync_helper(ovn_nb_synchronizer,
                                       self.networks,
                                       self.ports,
@@ -895,6 +920,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                       delete_dhcp_options_list,
                                       add_port_groups_list,
                                       del_port_groups_list,
+                                      create_metadata_list,
                                       test_logging)
 
     def test_ovn_nb_sync_mode_repair(self):
@@ -924,10 +950,11 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         delete_dhcp_options_list = []
         add_port_groups_list = []
         del_port_groups_list = []
+        create_metadata_list = []
 
         ovn_nb_synchronizer = ovn_db_sync.OvnNbSynchronizer(
             self.plugin, self.mech_driver.nb_ovn, self.mech_driver.sb_ovn,
-            'log', self.mech_driver)
+            ovn_const.OVN_DB_SYNC_MODE_LOG, self.mech_driver)
         self._test_ovn_nb_sync_helper(ovn_nb_synchronizer,
                                       self.networks,
                                       self.ports,
@@ -949,7 +976,8 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                       add_subnet_dhcp_options_list,
                                       delete_dhcp_options_list,
                                       add_port_groups_list,
-                                      del_port_groups_list)
+                                      del_port_groups_list,
+                                      create_metadata_list)
 
     def _test_ovn_nb_sync_calculate_routes_helper(self,
                                                   ovn_routes,
@@ -958,7 +986,7 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
                                                   expected_deleted):
         ovn_nb_synchronizer = ovn_db_sync.OvnNbSynchronizer(
             self.plugin, self.mech_driver.nb_ovn, self.mech_driver.sb_ovn,
-            'repair', self.mech_driver)
+            ovn_const.OVN_DB_SYNC_MODE_REPAIR, self.mech_driver)
         add_routes, del_routes = ovn_nb_synchronizer. \
             _calculate_routes_differences(ovn_routes, db_routes)
         self.assertEqual(add_routes, expected_added)
@@ -969,14 +997,13 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
         # add 2 routes to ovn
         ovn_routes = []
         db_routes = [{'nexthop': '20.0.0.100',
-                    'destination': '11.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '90.0.0.1',
-                    'destination': '0.0.0.0/0',
-                    'external_ids': {
-                        ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
-                        ovn_const.OVN_SUBNET_EXT_ID_KEY:
-                        'ext-subnet'}}]
+                      'destination': '11.0.0.0/24',
+                      'external_ids': {}},
+                     {'nexthop': '90.0.0.1',
+                      'destination': const.IPv4_ANY,
+                      'external_ids': {
+                          ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
+                          ovn_const.OVN_SUBNET_EXT_ID_KEY: 'ext-subnet'}}]
         expected_added = db_routes
         expected_deleted = []
         self._test_ovn_nb_sync_calculate_routes_helper(ovn_routes,
@@ -988,14 +1015,13 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
 
         # remove 2 routes from ovn
         ovn_routes = [{'nexthop': '20.0.0.100',
-                    'destination': '11.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '90.0.0.1',
-                    'destination': '0.0.0.0/0',
-                    'external_ids': {
-                        ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
-                        ovn_const.OVN_SUBNET_EXT_ID_KEY:
-                        'ext-subnet'}}]
+                       'destination': '11.0.0.0/24',
+                       'external_ids': {}},
+                      {'nexthop': '90.0.0.1',
+                       'destination': const.IPv4_ANY,
+                       'external_ids': {
+                            ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
+                            ovn_const.OVN_SUBNET_EXT_ID_KEY: 'ext-subnet'}}]
         db_routes = []
         expected_added = []
         expected_deleted = ovn_routes
@@ -1008,20 +1034,19 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
 
         # remove 2 routes from ovn, add 2 routes to ovn
         ovn_routes = [{'nexthop': '90.0.0.1',
-                    'destination': '0.0.0.0/0',
-                    'external_ids': {
-                        ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
-                        ovn_const.OVN_SUBNET_EXT_ID_KEY:
-                        'ext-subnet'}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '13.0.0.0/24',
-                    'external_ids': {}}]
+                       'destination': const.IPv4_ANY,
+                       'external_ids': {
+                            ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
+                            ovn_const.OVN_SUBNET_EXT_ID_KEY: 'ext-subnet'}},
+                      {'nexthop': '20.0.0.100',
+                       'destination': '13.0.0.0/24',
+                       'external_ids': {}}]
         db_routes = [{'nexthop': '20.0.0.100',
-                    'destination': '11.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '12.0.0.0/24',
-                    'external_ids': {}}]
+                      'destination': '11.0.0.0/24',
+                      'external_ids': {}},
+                     {'nexthop': '20.0.0.100',
+                     'destination': '12.0.0.0/24',
+                      'external_ids': {}}]
         expected_added = db_routes
         expected_deleted = ovn_routes
         self._test_ovn_nb_sync_calculate_routes_helper(ovn_routes,
@@ -1033,36 +1058,35 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
 
         # remove 2 routes from ovn, keep 2 routes
         ovn_routes = [{'nexthop': '20.0.0.100',
-                    'destination': '11.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '12.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '90.0.0.1',
-                    'destination': '0.0.0.0/0',
-                    'external_ids': {
-                        ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
-                        ovn_const.OVN_SUBNET_EXT_ID_KEY:
-                        'ext-subnet'}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '13.0.0.0/24',
-                    'external_ids': {}}]
+                       'destination': '11.0.0.0/24',
+                       'external_ids': {}},
+                      {'nexthop': '20.0.0.100',
+                       'destination': '12.0.0.0/24',
+                       'external_ids': {}},
+                      {'nexthop': '90.0.0.1',
+                       'destination': const.IPv4_ANY,
+                       'external_ids': {
+                            ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
+                            ovn_const.OVN_SUBNET_EXT_ID_KEY: 'ext-subnet'}},
+                      {'nexthop': '20.0.0.100',
+                       'destination': '13.0.0.0/24',
+                       'external_ids': {}}]
         db_routes = [{'nexthop': '20.0.0.100',
-                    'destination': '11.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '12.0.0.0/24',
-                    'external_ids': {}}]
+                      'destination': '11.0.0.0/24',
+                      'external_ids': {}},
+                     {'nexthop': '20.0.0.100',
+                     'destination': '12.0.0.0/24',
+                      'external_ids': {}}]
         expected_added = []
         expected_deleted = [{'nexthop': '90.0.0.1',
-                    'destination': '0.0.0.0/0',
-                    'external_ids': {
-                        ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
-                        ovn_const.OVN_SUBNET_EXT_ID_KEY:
-                        'ext-subnet'}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '13.0.0.0/24',
-                    'external_ids': {}}]
+                             'destination': const.IPv4_ANY,
+                             'external_ids': {
+                                 ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
+                                 ovn_const.OVN_SUBNET_EXT_ID_KEY:
+                                     'ext-subnet'}},
+                            {'nexthop': '20.0.0.100',
+                             'destination': '13.0.0.0/24',
+                             'external_ids': {}}]
         self._test_ovn_nb_sync_calculate_routes_helper(ovn_routes,
                                                        db_routes,
                                                        expected_added,
@@ -1072,35 +1096,33 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
 
         # add 2 routes to ovn, keep 2 routes
         ovn_routes = [{'nexthop': '20.0.0.100',
-                    'destination': '11.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '12.0.0.0/24',
-                    'external_ids': {}}]
+                       'destination': '11.0.0.0/24',
+                       'external_ids': {}},
+                      {'nexthop': '20.0.0.100',
+                       'destination': '12.0.0.0/24',
+                       'external_ids': {}}]
         db_routes = [{'nexthop': '20.0.0.100',
-                    'destination': '11.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '12.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '90.0.0.1',
-                    'destination': '0.0.0.0/0',
-                    'external_ids': {
-                        ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
-                        ovn_const.OVN_SUBNET_EXT_ID_KEY:
-                        'ext-subnet'}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '13.0.0.0/24',
-                    'external_ids': {}}]
+                      'destination': '11.0.0.0/24',
+                      'external_ids': {}},
+                     {'nexthop': '20.0.0.100',
+                      'destination': '12.0.0.0/24',
+                      'external_ids': {}},
+                     {'nexthop': '90.0.0.1',
+                      'destination': const.IPv4_ANY,
+                      'external_ids': {
+                          ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
+                          ovn_const.OVN_SUBNET_EXT_ID_KEY: 'ext-subnet'}},
+                     {'nexthop': '20.0.0.100',
+                      'destination': '13.0.0.0/24',
+                      'external_ids': {}}]
         expected_added = [{'nexthop': '90.0.0.1',
-                    'destination': '0.0.0.0/0',
-                    'external_ids': {
-                        ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
-                        ovn_const.OVN_SUBNET_EXT_ID_KEY:
-                        'ext-subnet'}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '13.0.0.0/24',
-                    'external_ids': {}}]
+                           'destination': const.IPv4_ANY,
+                           'external_ids': {
+                               ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
+                               ovn_const.OVN_SUBNET_EXT_ID_KEY: 'ext-subnet'}},
+                          {'nexthop': '20.0.0.100',
+                           'destination': '13.0.0.0/24',
+                           'external_ids': {}}]
         expected_deleted = []
         self._test_ovn_nb_sync_calculate_routes_helper(ovn_routes,
                                                        db_routes,
@@ -1111,48 +1133,46 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
 
         # add 2 routes to ovn, remove 2 routes from ovn, keep 2 routes
         ovn_routes = [{'nexthop': '20.0.0.100',
-                    'destination': '13.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '90.0.0.1',
-                    'destination': '0.0.0.0/0',
-                    'external_ids': {
-                        ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
-                        ovn_const.OVN_SUBNET_EXT_ID_KEY:
-                        'ext-subnet'}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '14.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '15.0.0.0/24',
-                    'external_ids': {}}]
+                       'destination': '13.0.0.0/24',
+                       'external_ids': {}},
+                      {'nexthop': '90.0.0.1',
+                       'destination': const.IPv4_ANY,
+                       'external_ids': {
+                            ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
+                            ovn_const.OVN_SUBNET_EXT_ID_KEY: 'ext-subnet'}},
+                      {'nexthop': '20.0.0.100',
+                       'destination': '14.0.0.0/24',
+                       'external_ids': {}},
+                      {'nexthop': '20.0.0.100',
+                       'destination': '15.0.0.0/24',
+                       'external_ids': {}}]
         db_routes = [{'nexthop': '20.0.0.100',
-                    'destination': '11.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '12.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '13.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '90.0.0.1',
-                    'destination': '0.0.0.0/0',
-                    'external_ids': {
-                        ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
-                        ovn_const.OVN_SUBNET_EXT_ID_KEY:
-                        'ext-subnet'}}]
+                      'destination': '11.0.0.0/24',
+                      'external_ids': {}},
+                     {'nexthop': '20.0.0.100',
+                      'destination': '12.0.0.0/24',
+                      'external_ids': {}},
+                     {'nexthop': '20.0.0.100',
+                      'destination': '13.0.0.0/24',
+                      'external_ids': {}},
+                     {'nexthop': '90.0.0.1',
+                      'destination': const.IPv4_ANY,
+                      'external_ids': {
+                          ovn_const.OVN_ROUTER_IS_EXT_GW: 'true',
+                          ovn_const.OVN_SUBNET_EXT_ID_KEY: 'ext-subnet'}}]
 
         expected_added = [{'nexthop': '20.0.0.100',
-                    'destination': '11.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '12.0.0.0/24',
-                    'external_ids': {}}]
+                           'destination': '11.0.0.0/24',
+                           'external_ids': {}},
+                          {'nexthop': '20.0.0.100',
+                           'destination': '12.0.0.0/24',
+                           'external_ids': {}}]
         expected_deleted = [{'nexthop': '20.0.0.100',
-                    'destination': '14.0.0.0/24',
-                    'external_ids': {}},
-                    {'nexthop': '20.0.0.100',
-                    'destination': '15.0.0.0/24',
-                    'external_ids': {}}]
+                             'destination': '14.0.0.0/24',
+                             'external_ids': {}},
+                            {'nexthop': '20.0.0.100',
+                             'destination': '15.0.0.0/24',
+                             'external_ids': {}}]
         self._test_ovn_nb_sync_calculate_routes_helper(ovn_routes,
                                                        db_routes,
                                                        expected_added,
@@ -1162,10 +1182,10 @@ class TestOvnNbSyncML2(test_mech_driver.OVNMechanismDriverTestCase):
 class TestIsRouterPortChanged(test_mech_driver.OVNMechanismDriverTestCase):
 
     def setUp(self):
-        super(TestIsRouterPortChanged, self).setUp()
+        super().setUp()
         self.ovn_nb_synchronizer = ovn_db_sync.OvnNbSynchronizer(
             self.plugin, self.mech_driver.nb_ovn, self.mech_driver.sb_ovn,
-            'log', self.mech_driver)
+            ovn_const.OVN_DB_SYNC_MODE_LOG, self.mech_driver)
 
         self.db_router_port = {
             'id': 'aa076509-915d-4b1c-8d9d-3db53d9c5faf',
